@@ -150,17 +150,17 @@ class HemisphereWindowExt:
                                            azimuth=azimuthT)
 
             geoStat = 'Geometry corrected' if delta else 'Equal mount'
-            t = f'Slewing dome:        {geoStat},'
-            t += f' az: {azimuthT:3.1f} delta: {delta:3.1f}'
+            t = f'Slewing dome:        [{geoStat}],'
+            t += f' AZ:[{azimuthT:3.1f}] delta: [{delta:3.1f}]'
             self.app.message.emit(t, 0)
 
         suc = self.app.mount.obsSite.startSlewing(slewType=slewType)
 
         if suc:
-            t = f'Slewing mount to AZ: [{azimuthT}], ALT: [{altitudeT}]'
+            t = f'Slewing mount to     AZ:[{azimuthT:3.1f}], ALT:[{altitudeT:3.1f}]'
             self.app.message.emit(t, 0)
         else:
-            t = f'Cannot slew to AZ: [{azimuthT}], ALT: [{altitudeT}]'
+            t = f'Cannot slew to       AZ:[{azimuthT:3.1f}], ALT:[{altitudeT:3.1f}]'
             self.app.message.emit(t, 2)
 
         return suc
@@ -182,8 +182,12 @@ class HemisphereWindowExt:
         azimuth = int(event.xdata + 0.5)
         altitude = int(event.ydata + 0.5)
 
-        question = 'Do you want to slew the mount to:'
-        question += f'\n\nAzimuth:\t{azimuth}°\nAltitude:\t{altitude}°'
+        question = '<b>Manual slewing to coordinate</b>'
+        question += '<br><br>Selected coordinates are:<br>'
+        question += f'<font color={self.M_BLUE}> Altitude: {altitude:3.1f}°'
+        question += f'   Azimuth: {azimuth:3.1f}°</font>'
+        question += '<br><br>Would you like to start slewing?<br>'
+
         suc = self.messageDialog(self, 'Slewing mount', question)
         if not suc:
             return False
@@ -191,11 +195,11 @@ class HemisphereWindowExt:
         suc = self.app.mount.obsSite.setTargetAltAz(alt_degrees=altitude,
                                                     az_degrees=azimuth)
         if not suc:
-            t = f'Cannot slew to AZ: [{azimuth}], ALT: [{altitude}]'
+            t = f'Cannot slew to       AZ:[{azimuth:3.1f}], ALT:[{altitude:3.1f}]'
             self.app.message.emit(t, 2)
             return False
 
-        t = f'Slewing mount to AZ: [{azimuth}], ALT: [{altitude}]'
+        t = f'Slewing mount to     AZ:[{azimuth:3.1f}], ALT:[{altitude:3.1f}]'
         self.app.message.emit(t, 0)
         suc = self.slewSelectedTarget(slewType='keep')
         return suc
@@ -374,6 +378,9 @@ class HemisphereWindowExt:
         """
         if not event.inaxes:
             return False
+        if not self.app.mount.model.numberStars:
+            self.app.message.emit('No model for alignment present!', 2)
+            return False
 
         if event.button == 1 and not event.dblclick:
             alignType = 'polar'
@@ -390,8 +397,19 @@ class HemisphereWindowExt:
 
         name = hip.name[index]
         ra, dec = hip.getAlignStarRaDecFromName(hip.name[index])
-        textFormat = 'Align: {0}\nDo you want to slew the mount to:\n\n{1}'
-        question = textFormat.format(alignType, name)
+        question = '<b>Polar / Ortho Alignment procedure</b>'
+        question += '<br><br>Selected alignment type: '
+        question += f'<font color={self.M_BLUE}>{alignType}.</font>'
+        question += '<br>Selected alignment star: '
+        question += f'<font color={self.M_BLUE}>{name}.</font>'
+        question += '<br>Would you like to start alignment?<br>'
+
+        isDAT = self.app.mount.setting.statusDualAxisTracking
+        warning = f'<br><i><font color={self.M_YELLOW}>'
+        warning += 'Dual Axis Tracking is actually enabled!<br>'
+        warning += 'It should be off during alignment process.</font></i>'
+
+        question = question + warning if isDAT else question
 
         suc = self.messageDialog(self, 'Slewing mount', question)
         if not suc:
@@ -400,10 +418,10 @@ class HemisphereWindowExt:
         suc = self.app.mount.obsSite.setTargetRaDec(ra_hours=ra,
                                                     dec_degrees=dec)
         if not suc:
-            self.app.message.emit(f'Cannot slew to: [{name}]', 2)
+            self.app.message.emit(f'Cannot slew to:      [{name}]', 2)
             return False
 
-        self.app.message.emit(f'Slewing mount to: [{name}]', 2)
+        self.app.message.emit(f'Align [{alignType}] to:    [{name}]', 1)
         suc = self.slewSelectedTarget(slewType=alignType)
         return suc
 
