@@ -16,6 +16,7 @@
 #
 ###########################################################
 # standard libraries
+from base.packageConfig import isAvailable
 import os
 
 # external packages
@@ -31,7 +32,8 @@ from astropy.visualization import AsinhStretch
 from astropy.visualization import imshow_norm
 from matplotlib.patches import Ellipse
 import matplotlib.pyplot as plt
-from colour_demosaicing import demosaicing_CFA_Bayer_bilinear
+if isAvailable:
+    from colour_demosaicing import demosaicing_CFA_Bayer_bilinear
 import sep
 
 # local import
@@ -798,7 +800,7 @@ class ImageWindow(toolsQtWidget.MWidget):
 
         self.image = self.image.astype('float32')
 
-        if 'BAYERPAT' in self.header:
+        if 'BAYERPAT' in self.header and isAvailable:
             self.image = demosaicing_CFA_Bayer_bilinear(self.image)
             self.image = np.dot(self.image, [0.2989, 0.5870, 0.1140])
 
@@ -836,20 +838,23 @@ class ImageWindow(toolsQtWidget.MWidget):
         focalLength = self.app.telescope.focalLength
 
         self.imageFileNameOld = self.imageFileName
-        self.app.camera.expose(imagePath=imagePath,
-                               expTime=self.expTime,
-                               binning=self.binning,
-                               subFrame=subFrame,
-                               fastReadout=fastReadout,
-                               focalLength=focalLength
-                               )
+        suc = self.app.camera.expose(imagePath=imagePath,
+                                     expTime=self.expTime,
+                                     binning=self.binning,
+                                     subFrame=subFrame,
+                                     fastReadout=fastReadout,
+                                     focalLength=focalLength
+                                     )
+        if not suc:
+            text = f'Cannot expose:       [{os.path.basename(imagePath)}]'
+            self.app.message.emit(text, 2)
+            return False
 
         text = f'Exposing:            [{os.path.basename(imagePath)}]'
         self.app.message.emit(text, 0)
         text = f'Duration:{self.expTime:3.0f}s  '
         text += f'Bin:{self.binning:1.0f}  Sub:{subFrame:3.0f}%'
         self.app.message.emit(f'                     {text}', 0)
-
         return True
 
     def exposeImageDone(self, imagePath=''):
