@@ -77,26 +77,24 @@ class SettMount(object):
         bAddress = self.ui.mountWolAddress.text().strip()
         bPort = self.ui.mountWolPort.text().strip()
         bPort = (int(bPort) if bPort else 0)
-        if self.app.mount.bootMount(bAddress=bAddress,
-                                    bPort=bPort):
+        suc = self.app.mount.bootMount(bAddress=bAddress,
+                                       bPort=bPort)
+        if suc:
             self.app.message.emit('Sent boot command to mount', 0)
-            return True
-
         else:
             self.app.message.emit('Mount cannot be booted', 2)
-            return False
+        return suc
 
     def mountShutdown(self):
         """
         :return:
         """
-        if self.app.mount.shutdown():
+        suc = self.app.mount.shutdown()
+        if suc:
             self.app.message.emit('Shutting mount down', 0)
-            return True
-
         else:
             self.app.message.emit('Mount cannot be shutdown', 2)
-            return False
+        return suc
 
     def checkFormatMAC(self, value):
         """
@@ -155,6 +153,7 @@ class SettMount(object):
             port = 3490
 
         self.app.mount.host = (self.ui.mountHost.text(), port)
+        self.app.hostChanged.emit()
         return True
 
     def mountMAC(self):
