@@ -16,22 +16,22 @@
 #
 ###########################################################
 # standard libraries
-import platform
 import os
-import re
+import logging
 
 # external packages
 from PyQt5.QtWidgets import QWidget, QDesktopWidget, QFileDialog, QMessageBox
-from PyQt5.QtGui import QPalette, QIcon, QPixmap
+from PyQt5.QtWidgets import QTableWidgetItem
+from PyQt5.QtGui import QPalette, QIcon, QPixmap, QColor, QPainter, QImage
 from PyQt5.QtCore import QSortFilterProxyModel, QDir, QObject, pyqtSignal
 from PyQt5.QtCore import Qt, QSize, QEvent
-from skyfield.api import Angle
 import numpy as np
+from qimage2ndarray import rgb_view, array2qimage
 
 # local imports
 from gui.utilities.stylesQtCss import Styles
 from gui.utilities.toolsMatplotlib import ToolsMatplotlib
-from mountcontrol.convert import sexagesimalizeToInt
+from mountcontrol.convert import formatHstrToText, formatDstrToText
 
 __all__ = [
     'MWidget',
@@ -61,6 +61,7 @@ class QMultiWait(QObject):
     in addition all received signals could be reset
     """
     ready = pyqtSignal()
+    log = logging.getLogger(__name__)
 
     def __init__(self):
         super().__init__()
@@ -75,8 +76,10 @@ class QMultiWait(QObject):
     def checkSignal(self):
         sender = self.sender()
         self.waitready.add(sender)
+        self.log.debug(f'QMultiWait [{self}]: [{self.waitready}]')
 
         if len(self.waitready) == len(self.waitable):
+            self.log.debug(f'Firing QMultiWait for [{self}]')
             self.ready.emit()
 
     def resetSignals(self):
@@ -90,6 +93,31 @@ class QMultiWait(QObject):
         self.waitready = set()
 
 
+class QCustomTableWidgetItem(QTableWidgetItem):
+    """
+    This class reimplements the comparison for item, which are normally float
+    values as the standard sorting in this item only supports strings.
+    """
+    def __init__(self, value):
+        super().__init__(value)
+
+    def __lt__(self, other):
+        if (isinstance(other, QCustomTableWidgetItem)):
+            selfData = self.data(Qt.EditRole)
+            if selfData == '':
+                selfDataValue = 99
+            else:
+                selfDataValue = float(selfData)
+            otherData = other.data(Qt.EditRole)
+            if otherData == '':
+                otherDataValue = 99
+            else:
+                otherDataValue = float(otherData)
+            return selfDataValue < otherDataValue
+        else:
+            return QTableWidgetItem.__lt__(self, other)
+
+
 class MWidget(QWidget, Styles, ToolsMatplotlib):
     """
     MWidget defines the common parts for all windows used in MountWizzard 4 and
@@ -123,7 +151,72 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         self.setWindowIcon(QIcon(':/icon/mw4.png'))
 
     @staticmethod
-    def wIcon(gui=None, name=''):
+    def findIndexValue(ui, searchString, relaxed=False):
+        """
+        :param ui:
+        :param searchString:
+        :param relaxed:
+        :return:
+        """
+        for index in range(ui.model().rowCount()):
+            modelIndex = ui.model().index(index, 0)
+            indexValue = ui.model().data(modelIndex)
+
+            if not indexValue:
+                continue
+
+            if relaxed:
+                if searchString in indexValue:
+                    return index
+
+            else:
+                if indexValue.startswith(searchString):
+                    return index
+
+        return 0
+
+    def img2pixmap(self, img, detect=None, color=None):
+        """
+        :param img:
+        :param detect:
+        :param color:
+        :return:
+        """
+        image = QImage(img)
+        image.convertToFormat(QImage.Format_RGB32)
+        imgArr = rgb_view(image)
+        if detect is not None and color is not None:
+            detect = self.hex2rgb(detect)
+            target = self.hex2rgb(color)
+            imgArr[np.where((imgArr == detect).all(axis=2))] = target
+        image = array2qimage(imgArr)
+        pixmap = QPixmap().fromImage(image)
+        return pixmap
+
+    @staticmethod
+    def svg2pixmap(svg, color='black'):
+        """
+        :param svg:
+        :param color:
+        :return:
+        """
+        img = QPixmap(svg)
+        qp = QPainter(img)
+        qp.setCompositionMode(QPainter.CompositionMode_SourceIn)
+        qp.fillRect(img.rect(), QColor(color))
+        qp.end()
+        return img
+
+    def svg2icon(self, svg, color='black'):
+        """
+        :param svg:
+        :param color:
+        :return:
+        """
+        img = self.svg2pixmap(svg, color)
+        return QIcon(img)
+
+    def wIcon(self, gui=None, name=''):
         """
         widget icon adds an icon to a gui element like an button.
 
@@ -136,7 +229,7 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         if not name:
             return False
 
-        icon = QIcon(f':/icon/{name}.svg')
+        icon = self.svg2icon(f':/icon/{name}.svg', self.M_BLUE)
         gui.setIcon(icon)
         gui.setIconSize(QSize(16, 16))
         gui.setProperty('alignLeft', True)
@@ -144,20 +237,6 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         gui.style().polish(gui)
         return True
 
-    def getStyle(self):
-        """
-        getStyle return the actual stylesheet for the used platform.
-        As the font sizes vary between Darwin and Windows / Ubuntu there were
-        two sets of stylesheets used. a basic stylesheet adds undifferentiated
-        properties.
-
-        :return:    actual stylesheet string
-        """
-        if platform.system() == 'Darwin':
-            return self.MAC_STYLE + self.BASIC_STYLE
-        else:
-            return self.NON_MAC_STYLE + self.BASIC_STYLE
-
     def initUI(self):
         """
         init_UI makes the basic initialisation of the GUI. is sets the window
@@ -167,9 +246,7 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
 
         :return:    true for test purpose
         """
-        self.setWindowFlags(self.windowFlags())
-        style = self.getStyle()
-        self.setStyleSheet(style)
+        self.setStyleSheet(self.mw4Style)
         self.setMouseTracking(True)
         self.setWindowIcon(QIcon(':/mw4.ico'))
         return True
@@ -258,7 +335,7 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         dlg = QFileDialog()
         dlg.setOptions(QFileDialog.DontUseNativeDialog)
         dlg.setWindowIcon(QIcon(':/mw4.ico'))
-        dlg.setStyleSheet(self.getStyle())
+        dlg.setStyleSheet(self.mw4Style)
         dlg.setViewMode(QFileDialog.List)
         dlg.setModal(True)
         if reverseOrder:
@@ -299,7 +376,8 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         """
         msg = QMessageBox()
         msg.setWindowModality(Qt.ApplicationModal)
-        msg.setStyleSheet(self.getStyle())
+        msg.setStyleSheet(self.mw4Style)
+        msg.setTextFormat(Qt.AutoText)
         msg.setWindowTitle(title)
         pixmap = QPixmap(':/icon/question.svg').scaled(64, 64)
         msg.setIconPixmap(pixmap)
@@ -459,13 +537,10 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         if not widget:
             return None
 
-        class MouseDoubleClickEventFilter(QObject):
+        class MouseClickEventFilter(QObject):
             clicked = pyqtSignal(object)
 
             def eventFilter(self, obj, event):
-                if obj != widget:
-                    return False
-
                 if event.type() not in [QEvent.MouseButtonRelease,
                                         QEvent.FocusIn]:
                     return False
@@ -477,11 +552,12 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
 
                 return False
 
-        doubleClickEventFilter = MouseDoubleClickEventFilter(widget)
-        widget.installEventFilter(doubleClickEventFilter)
-        return doubleClickEventFilter.clicked
+        clickEventFilter = MouseClickEventFilter(widget)
+        widget.installEventFilter(clickEventFilter)
+        return clickEventFilter.clicked
 
-    def guiSetText(self, ui, formatElement, value=None):
+    @staticmethod
+    def guiSetText(ui, formatElement, value=None):
         """
         :param ui:
         :param formatElement:
@@ -497,9 +573,9 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         elif isinstance(value, (list, np.ndarray)) and len(value) == 0:
             text = '-'
         elif formatElement.startswith('HSTR'):
-            text = self.formatHstrToText(value)
+            text = formatHstrToText(value)
         elif formatElement.startswith('DSTR'):
-            text = self.formatDstrToText(value)
+            text = formatDstrToText(value)
         elif formatElement.startswith('D'):
             formatStr = '{0:' + formatElement.lstrip('D') + '}'
             text = formatStr.format(value.degrees)
@@ -522,7 +598,7 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         ui.setText(text)
         return True
 
-    def guiSetStyle(self, ui, pStyle='', value=None, pVals=['', '', '']):
+    def guiSetStyle(self, ui, pStyle='', value=None, pVals=None):
         """
         :param ui:
         :param pStyle:
@@ -530,6 +606,8 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         :param pVals:
         :return:
         """
+        if pVals is None:
+            pVals = ['', '', '']
         if not pStyle:
             return False
         if value is None:
@@ -567,199 +645,15 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         driver = searchD.get(sender, '')
         return driver
 
-    @staticmethod
-    def formatLatLonToAngle(value, pf):
+    def checkUpdaterOK(self):
         """
-        :param value:
-        :param pf: double character, first indicates the negative sign
         :return:
         """
-        if value is None:
-            return None
-
-        value = value.strip()
-        p1 = re.compile(r'(\d{1,3})([' + pf + r'])\s*(\d\d)?\s*(\d\d)?[.,]?(\d*)?')
-        p2 = re.compile(r'([-+]?)(\d{1,3})[.,]?(\d*)?')
-        isSexagesimal = p1.fullmatch(value) is not None
-        isFloat = p2.fullmatch(value) is not None
-
-        elements = p2.split(value)
-        if isFloat:
-            angle = float(value.replace(',', '.'))
-
-        elif isSexagesimal:
-            angle = float(elements[2])
-            if len(elements) > 5:
-                angle += float(elements[6]) / 60
-            if len(elements) > 9:
-                angle += float(elements[10]) / 3600
-            if elements[4].startswith(pf[0]):
-                angle = -angle
-        else:
-            return None
-
-        if 'N' in pf:
-            maxAbs = 90
-        else:
-            maxAbs = 180
-
-        if angle > maxAbs:
-            return None
-        elif angle < -maxAbs:
-            return None
-
-        angle = Angle(degrees=angle)
-        return angle
-
-    def convertLatToAngle(self, value):
-        """
-        :param value:
-        :return:
-        """
-        angle = self.formatLatLonToAngle(value, 'SN')
-        return angle
-
-    def convertLonToAngle(self, value):
-        """
-        :param value:
-        :return:
-        """
-        angle = self.formatLatLonToAngle(value, 'WE')
-        return angle
-
-    @staticmethod
-    def convertRaToAngle(value):
-        """
-        :param value:
-        :return:
-        """
-        if value is None:
-            return None
-
-        value = value.strip()
-        p1 = re.compile(r'([+-]?)(\d{1,3})H\s*(\d\d)?\s*(\d\d)?[.,]?(\d*)?')
-        p2 = re.compile(r'([+-]?)(\d{1,3})\s+(\d\d)?\s*(\d\d)?[.,]?(\d*)?')
-        p3 = re.compile(r'([+-]?)(\d{1,3})[.,]?(\d*)?')
-        isP1 = p1.fullmatch(value) is not None
-        isP2 = p2.fullmatch(value) is not None
-        isSexagesimal = isP1 or isP2
-        isFloat = p3.fullmatch(value) is not None
-
-        if isP1:
-            elements = p1.split(value)
-        elif isP2:
-            elements = p2.split(value)
-        else:
-            elements = ''
-
-        if isFloat:
-            angle = float(value.replace(',', '.'))
-        elif isSexagesimal:
-            angle = float(elements[2])
-            if elements[3] is not None:
-                angle += float(elements[3]) / 60
-            if elements[4] is not None:
-                angle += float(elements[4]) / 3600
-        else:
-            return None
-
-        if angle >= 24:
-            return None
-        if angle < 0:
-            return None
-        if isFloat:
-            angle = Angle(hours=angle / 360 * 24)
-        elif isSexagesimal:
-            angle = Angle(hours=angle)
-
-        return angle
-
-    @staticmethod
-    def convertDecToAngle(value):
-        """
-        :param value:
-        :return:
-        """
-        if value is None:
-            return None
-
-        value = value.strip()
-        p1 = re.compile(r'([+-]?)(\d{1,3})Deg\s*(\d\d)?\s*(\d\d)?[.,]?(\d*)?')
-        p2 = re.compile(r'([+-]?)(\d{1,3})\s+(\d\d)?\s*(\d\d)?[.,]?(\d*)?')
-        p3 = re.compile(r'([+-]?)(\d{1,3})[.,]?(\d*)?')
-        isP1 = p1.fullmatch(value) is not None
-        isP2 = p2.fullmatch(value) is not None
-        isSexagesimal = isP1 or isP2
-        isFloat = p3.fullmatch(value) is not None
-
-        if isP1:
-            elements = p1.split(value)
-        elif isP2:
-            elements = p2.split(value)
-        else:
-            elements = ''
-
-        if isFloat:
-            angle = float(value.replace(',', '.'))
-
-        elif isSexagesimal:
-            angle = float(elements[2])
-            if elements[3] is not None:
-                angle += float(elements[3]) / 60
-            if elements[4] is not None:
-                angle += float(elements[4]) / 3600
-            if elements[1].startswith('-'):
-                angle = -angle
-        else:
-            return None
-
-        if angle > 90:
-            return None
-        if angle < -90:
-            return None
-
-        angle = Angle(degrees=angle)
-        return angle
-
-    @staticmethod
-    def formatHstrToText(angle):
-        """
-        :param angle:
-        :return:
-        """
-        sgn, h, m, s, frac = sexagesimalizeToInt(angle.hours, 0)
-        text = f'{h:02d} {m:02d} {s:02d}'
-        return text
-
-    @staticmethod
-    def formatDstrToText(angle):
-        """
-        :param angle:
-        :return:
-        """
-        sgn, d, m, s, frac = sexagesimalizeToInt(angle.degrees, 0)
-        sign = '+' if sgn >= 0 else '-'
-        text = f'{sign}{d:02d} {m:02d} {s:02d}'
-        return text
-
-    @staticmethod
-    def formatLatToText(angle):
-        """
-        :param angle:
-        :return:
-        """
-        sgn, h, m, s, frac = sexagesimalizeToInt(angle.degrees, 0)
-        sign = 'N' if sgn >= 0 else 'S'
-        text = f'{h:02d}{sign} {m:02d} {s:02d}'
-        return text
-
-    @staticmethod
-    def formatLonToText(angle):
-        """
-        :param angle:
-        :return:
-        """
-        sgn, h, m, s, frac = sexagesimalizeToInt(angle.degrees, 0)
-        sign = 'E' if sgn >= 0 else 'W'
-        text = f'{h:03d}{sign} {m:02d} {s:02d}'
-        return text
+        if not self.app.automation:
+            self.app.message.emit('Not running windows - upload not possible', 2)
+            return False
+        if not self.app.automation.installPath:
+            self.app.message.emit('No 10micron updater available - upload not '
+                                  'possible', 2)
+            return False
+        return True
