@@ -20,37 +20,20 @@
 
 # local imports
 from base.alpacaClass import AlpacaClass
-from base.alpacaBase import Covercalibrator
 
 
 class CoverAlpaca(AlpacaClass):
     """
-    the class Dome inherits all information and handling of the Dome device. there will be
-    some parameters who will define the slewing position of the dome relating to the
-    mount.dome = DomeAlpaca(app=None)
     """
 
-    __all__ = ['CoverAlpaca',
-               ]
-
-    CYCLE_POLL_DATA = 1000
+    __all__ = ['CoverAlpaca']
 
     def __init__(self, app=None, signals=None, data=None):
         super().__init__(app=app, data=data, threadPool=app.threadPool)
 
-        # as we have in the base class only the base client there, we will get more
-        # specialized with Dome (which is derived from the base class)
-        self.client = Covercalibrator()
-        self.signals = signals
+        self.alpacaSignals = signals
         self.data = data
 
-    def getInitialConfig(self):
-        """
-        :return: true for test purpose
-        """
-        super().getInitialConfig()
-        return True
-
     def workerPollData(self):
         """
         :return: true for test purpose
@@ -59,7 +42,7 @@ class CoverAlpaca(AlpacaClass):
         if not self.deviceConnected:
             return False
 
-        state = self.client.coverstate()
+        state = self.getAlpacaProperty('coverstate')
         stateText = states[state]
         self.storePropertyToData(stateText, 'Status.Cover')
         return True
@@ -71,7 +54,7 @@ class CoverAlpaca(AlpacaClass):
         if not self.deviceConnected:
             return False
 
-        self.client.closecover()
+        self.getAlpacaProperty('closecover')
         return True
 
     def openCover(self):
@@ -81,7 +64,7 @@ class CoverAlpaca(AlpacaClass):
         if not self.deviceConnected:
             return False
 
-        self.client.opencover()
+        self.getAlpacaProperty('opencover')
         return True
 
     def haltCover(self):
@@ -91,7 +74,7 @@ class CoverAlpaca(AlpacaClass):
         if not self.deviceConnected:
             return False
 
-        self.client.haltcover()
+        self.getAlpacaProperty('haltcover')
         return True
 
     def lightOn(self):
@@ -101,8 +84,8 @@ class CoverAlpaca(AlpacaClass):
         if not self.deviceConnected:
             return False
 
-        brightness = self.client.brightness()
-        self.client.calibratoron(Brightness=brightness)
+        brightness = self.getAlpacaProperty('brightness')
+        self.setAlpacaProperty('calibratoron', Brightness=brightness)
         return True
 
     def lightOff(self):
@@ -112,7 +95,7 @@ class CoverAlpaca(AlpacaClass):
         if not self.deviceConnected:
             return False
 
-        self.client.calibratoroff()
+        self.getAlpacaProperty('calibratoroff')
         return True
 
     def lightIntensity(self, value):
@@ -123,5 +106,5 @@ class CoverAlpaca(AlpacaClass):
         if not self.deviceConnected:
             return False
 
-        self.client.calibratoron(Brightness=value)
+        self.setAlpacaProperty('calibratoron', Brightness=value)
         return True
