@@ -25,21 +25,13 @@ from base.indiClass import IndiClass
 
 class SensorWeatherIndi(IndiClass):
     """
-    the class SensorWeatherIndi inherits all information and handling of the SensorWeather device
-
-        >>> SensorWeatherIndi(host=None,
-        >>>         name=''
-        >>>         )
     """
 
-    __all__ = ['SensorWeatherIndi',
-               ]
-    UPDATE_RATE = 1
+    __all__ = ['SensorWeatherIndi']
 
     def __init__(self, app=None, signals=None, data=None):
-        super().__init__(app=app, data=data, threadPool=app.threadPool)
-
         self.signals = signals
+        super().__init__(app=app, data=data, threadPool=app.threadPool)
         self.data = data
 
     def setUpdateConfig(self, deviceName):
