@@ -33,13 +33,9 @@ class PegasusUPBIndi(IndiClass):
     __all__ = ['PegasusUPBIndi',
                ]
 
-    # update rate to 1000 milli seconds for setting indi server
-    UPDATE_RATE = 1000
-
     def __init__(self, app=None, signals=None, data=None):
-        super().__init__(app=app, data=data, threadPool=app.threadPool)
-
         self.signals = signals
+        super().__init__(app=app, data=data, threadPool=app.threadPool)
         self.data = data
         self.modelVersion = 0
 
