@@ -23,12 +23,10 @@ from base.ascomClass import AscomClass
 
 
 class TelescopeAscom(AscomClass):
-    """     the class Telescope inherits all information and handling of the
-            Telescope device.
+    """
     """
 
-    __all__ = ['TelescopeAscom',
-               ]
+    __all__ = ['TelescopeAscom']
 
     def __init__(self, app=None, signals=None, data=None):
         super().__init__(app=app, data=data, threadPool=app.threadPool)
@@ -47,6 +45,7 @@ class TelescopeAscom(AscomClass):
             value = value * 1000
 
         self.storePropertyToData(value, 'TELESCOPE_INFO.TELESCOPE_APERTURE')
+
         value = self.getAscomProperty('FocalLength')
         if isinstance(value, float):
             value = value * 1000
